@@ -75,10 +75,19 @@ class Selection(object):
         Return the top, left, bottom and right margins of the selection.
 
         :return: Tuple of (top,left,bottom,right) margins in px
-        :rtype: tuple, list
+        :rtype: tuple
         """
         return self.margin_top, self.margin_left, self.margin_bottom, self.margin_right
 
+    def get_xy_margin(self):
+        """
+        Returns the x/y margins of the selection.
+
+        :return: Tuple of (x,y) margins
+        :rtype: tuple
+        """
+        return self.margin_left + self.margin_right, self.margin_top + self.margin_bottom
+
     def get_width(self):
         """
         Return the selection width (px) as sum of left and right margins.
